
/**************************************************************************************
**
**  The Osiris application compares one catalog of executable files
**  with another catalog of executable files. Osiris catalogs specified
**  directories of files (including MD5 hashes, modification dates,
**  and file attributes into a specified database.
**
**  Copyright (C) 2000  - the shmoo group -
**
**  This program is free software; you can redistribute it and/or
**  modify it under the terms of the GNU General Public License
**  as published by the Free Software Foundation; either version 2
**  of the License, or (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
**
**************************************************************************************/

/**************************************************************************************
**
**    The Shmoo Group (TSG)
**
**    File:      file_filter.h
**    Author:    Brian Wotring
**
**    Date:      January 27, 2000.
**    Project:   osiris ( UNIX ).
**
**************************************************************************************/

#ifndef _FILE_FILTER_H
#define _FILE_FILTER_H

#include <stdio.h>
#include <sys/stat.h>
#include <string.h>
#include <unistd.h>

#include "file_utilities.h"

/* for now, we have a simple mask to enable the */
/* filter to be set by using a bitwise OR of    */
/* the constants below to specify which types   */
/* of files can pass through the filter.        */

#define FILTER_MASK        0x007

#define FILTER_ALL	   0x0
#define FILTER_ELF         0x001
#define FILTER_EXECUTABLE  0x002
#define FILTER_SCRIPT      0x004


typedef struct file_filter
{
    unsigned int definition;

} file_filter;


void set_file_filter( file_filter *filter, int filter_definition );
void add_to_file_filter( file_filter *filter, int filter_definition );

int file_is_allowed( file_filter *filter, const char *file_path );

int file_is_elf( const char *file_path );
int file_is_executable( const char *file_path );
int file_is_shell_script( const char *file_path );


#endif
