
/**************************************************************************************
**
**  The Osiris application compares one catalog of executable files
**  with another catalog of executable files. Osiris catalogs specified
**  directories of files (including MD5 hashes, modification dates,
**  and file attributes into a specified database.
**
**  Copyright (C) 2000  - the shmoo group -
**
**  This program is free software; you can redistribute it and/or
**  modify it under the terms of the GNU General Public License
**  as published by the Free Software Foundation; either version 2
**  of the License, or (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
** 
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
**
**************************************************************************************/

/**************************************************************************************
**
**    The Shmoo Group (TSG)
**
**    File:      osiris.h
**    Author:    Brian Wotring
**
**    Date:      January 4, 2000.
**    Project:   osiris ( UNIX ).
**
**************************************************************************************/


#ifndef OSIRIS_H_
#define OSIRIS_H_


#include "utilities.h"
#include "entry.h"

#include "hash_handler.h"
#include "database_handler.h"

#include "file_utilities.h"
#include "file_filter.h"

#include <unistd.h>
#include <dirent.h>

#include <sys/stat.h>
#include <sys/types.h>

#include <limits.h>
#include <time.h>

#include "gdbm.h"
#include <fcntl.h>


/* global data. */

char *directory_list[100];
int directory_list_size			= 0;

int database_mode			= 0;      /* log entries to database.              */
int console_mode 			= 0;      /* log entries to console.               */
int symlink_mode			= 0;      /* traverse symbolic links.              */
int quiet_mode				= 0;      /* no messages to console.               */
int force_mode				= 0;      /* overwrite database without prompting. */

char database_path[4096]		= "\0";
database *db;

file_filter filter;

unsigned int file_logged_count		= 0;
unsigned int file_scanned_count		= 0;
unsigned int file_unreadable_count	= 0;

char program_name[50]			= "osiris";
char program_version[50]		= "1.2";

char start_time[40]			= "\0";
char end_time[40]			= "\0";

/* method prototypes. */

void init( int argument_count, char *argument_list[] );
void quit();

void print_usage();
void print_startup_info();
void print_program_info();
void print_results();

void check_arguments( int argument_count, char *argument_list[] );
void show_current_counters();

void open_database_files();
void close_database_files();

void process();
int  process_entry( entry *file_entry );

void process_file( const char *file_path );
void process_symlink( const char *file_path );
void process_directory( const char *directory_path );

#endif
