
/**************************************************************************************
**
**  The Osiris application compares one catalog of executable files
**  with another catalog of executable files. Osiris catalogs specified
**  directories of files (including MD5 hashes, modification dates,
**  and file attributes into a specified database.
**
**  Copyright (C) 2000  - the shmoo group -
**
**  This program is free software; you can redistribute it and/or
**  modify it under the terms of the GNU General Public License
**  as published by the Free Software Foundation; either version 2
**  of the License, or (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
** 
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
**
**************************************************************************************/

/**************************************************************************************
**
**    The Shmoo Group (TSG)
**
**    File:      scale.h
**    Author:    Brian Wotring
**
**    Date:      January 4, 2000.
**    Project:   osiris ( UNIX ).
**
**************************************************************************************/

#ifndef SCALE_H_
#define SCALE_H_

#include "entry.h"
#include "utilities.h"
#include "string_list.h"
#include "database_handler.h"
#include "file_utilities.h"


/* global data. */

FILE *output_file		= NULL;
char output_file_path[4096]	= "\0";

int console_mode 		= 0;
int psychonazi_mode		= 0;
int pretty_mode			= 0;

database *left_database;
database *right_database;

char left_database_path[4096]	= "\0";
char right_database_path[4096]	= "\0";

char program_name[50]		= "scale\0";
char program_version[50]	= "1.2\0";

/* counters. */

unsigned int file_count		= 0;
unsigned int file_new_count	= 0;
unsigned int file_missing_count = 0;

unsigned int file_hash_diff	= 0;
unsigned int file_date_diff	= 0;
unsigned int file_attrib_diff	= 0;
unsigned int file_uid_diff	= 0;
unsigned int file_gid_diff	= 0;
unsigned int file_suid_diff	= 0;

/* data for checking for duplicate hashes ( psychonazi mode ) */

int left_duplicate_count 	= 0;
int right_duplicate_count       = 0;

string_list *left_duplicates	= NULL;
string_list *right_duplicates	= NULL;


/* method prototypes. */

void init( int argument_count, char *argument_list[] );
void quit();

void print_usage();
void print_program_info();
void print_scale_results();

void print_output_file_header();
void print_output_file_compare_header();

void check_arguments( int argument_count, char *argument_list[] );
void process();

void open_database_files();
void close_database_files();

void check_for_missing_entries();
void check_for_new_entries();

void check_for_duplicate_left_hashes();
void check_for_duplicate_right_hashes();

void log_duplicate_left_hashes();
void log_duplicate_right_hashes();

void compare_entry_hash( entry *left_entry, entry *right_entry );
void compare_entry_date( entry *left_entry, entry *right_entry );
void compare_entry_attributes( entry *left_entry, entry *right_entry );

void compare_entry_uid( entry *left_entry, entry *right_entry );
void compare_entry_gid( entry *left_entry, entry *right_entry );
void compare_entry_suid( entry *left_entry, entry *right_entry );

char * get_entry_element_with_index( entry *file_entry, unsigned int index );

#endif
