
#include "string_list.h"
#include "utilities.h"

string_list * new_string_list()
{
    string_list *list = (string_list *)safemalloc( sizeof( string_list ) );

    list->list     = (list_entry **)safemalloc( sizeof(list_entry *) * INITIAL_LIST_SIZE );
    list->max_size = INITIAL_LIST_SIZE;
    list->size     = 0;

    return list;
}

void destroy_string_list( string_list *list )
{
    int index;

    if( list == NULL )
	return;

    for( index = 0; index < list->size; index++ )
	destroy_list_entry( (list->list)[index] );

    free( list->list );
    free( list );
}

void destroy_list_entry( list_entry *entry )
{
    if( entry == NULL )
	return;

    if( entry->data )
        free( entry->data );

    if( entry->name )
        free( entry->name );

    free( entry );
}


int add_item_with_name( string_list *list, const char *item, const char *name )
{
    list_entry *new_entry;
   
    if( list == NULL )
	return 0;

    new_entry = (list_entry *)safemalloc( sizeof( list_entry ) );

    new_entry->data = NULL;
    new_entry->name = NULL;

    /* if item was given, create space and copy into entry. */

    if( item != NULL )
    {
        new_entry->data  = (char *)safemalloc( strlen( item ) + 1 );
        strcpy( new_entry->data, item );
    }

    /* if name was given, copy into entry. */
 
    if( name != NULL )
    {
	new_entry->name = (char *)safemalloc( strlen( name ) + 1 );
	strcpy( new_entry->name, name );
    }

    list->list[list->size] = new_entry;
    list->size++;

    if( list->size == list->max_size )
	double_size( list );
 
    return 1;
}


void double_size( string_list *list )
{
    int index;
    list_entry **new_entry_list;

    if( list == NULL )
	return;

    list->max_size = ( list->max_size * 2 );
    new_entry_list = (list_entry **)safemalloc( sizeof(list_entry *) * list->max_size );
    /* copy over the new data. */

    for( index = 0; index < list->size; index++ )
	new_entry_list[index] = list->list[index];

    /* free the old list's entry list. */
   
    free( list->list );
    list->list = new_entry_list;
}


int append_to_item_with_name( string_list *list, const char *item, const char *name )
{
    int index;

    if( list == NULL || item == NULL || name == NULL )
	return 0;

    for( index = 0; index < list->size; index++ )
    {
	if( strcmp( list->list[index]->name, name ) == 0 )
	{
	    unsigned int new_size   = ( strlen( item ) + strlen( list->list[index]->data ) + 1 );
	    char *old_data 	    = list->list[index]->data;
	
	    list->list[index]->data = (char *)safemalloc( new_size );

	    strcpy( list->list[index]->data, old_data );
  	    strcat( list->list[index]->data, item );

	    free( old_data );
	
	    return 1;
	}
    }

    return 0;
}

int item_with_name_exists( string_list *list, const char *name )
{
    int index;

    if( list == NULL || name == NULL )
	return 0;

    for( index = 0; index < list->size; index++ )
    {
        char *list_item_name = list->list[index]->name;

	if( list_item_name && strcmp( list_item_name, name ) == 0 )
	    return 1;
    }

    return 0;
}


void dump( string_list *list )
{
    int index;

    for( index = 0; index < list->size; index++ )
	log_message( "name: %s, data: %s", list->list[index]->name, list->list[index]->data );
}
