
/**************************************************************************************
**
**  The Osiris application compares one catalog of executable files
**  with another catalog of executable files. Osiris catalogs specified
**  directories of files (including MD5 hashes, modification dates,
**  and file attributes into a specified database.
**
**  Copyright (C) 2000  - the shmoo group -
**
**  This program is free software; you can redistribute it and/or
**  modify it under the terms of the GNU General Public License
**  as published by the Free Software Foundation; either version 2
**  of the License, or (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
** 
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
**
**************************************************************************************/

/**************************************************************************************
**
**    The Shmoo Group (TSG)
**
**    File:      utilities.c
**    Author:    Brian Wotring
**
**    Date:      January 4, 2000.
**    Project:   osiris ( UNIX ).
**
**************************************************************************************/


#include "utilities.h"


/**************************************************************************************
**
**    Function: char * safemalloc
** 
**    Purpose:  attempts to allocate memory with malloc.  If succesful, this
**              function is transparent in action, otherwise, fatal exit.  If
**              malloc fails, most likely other things will do so soon.
**    
**    Return:   Upon success, a pointer to the newly allocated memory.
**  
**
**************************************************************************************/

void *safemalloc( size_t size )
{
    char *new;

    if( size <= 0 )
        size = 1;

    new = malloc( size );

    if( new == NULL )
    {
        log_message_debug( "fn_utility: malloc failed, exiting" );
        exit (1);
    }

	log_message_debug( "fn_utility: malloc was able to allocate %d bytes.", (int)size );

    return new;
}

/**************************************************************************************
**
**    Function: log_message
** 
**    Purpose:  similar to printf, but will add a new line, and flush
**		the output stream.
**    
**    Return:   none.
**  
**
**************************************************************************************/

void log_message( char *message, ... )
{
    va_list ap;

    va_start( ap, message );
    vfprintf( stdout, message, ap );
    va_end( ap );

    fprintf( stdout, "\n" );
    fflush( stdout );
}

/**************************************************************************************
**
**    Function: log_message_exit
** 
**    Purpose:  logs message just like log_message, then exits safely.
**    
**    Return:   doesn't.
**  
**
**************************************************************************************/

void log_message_exit( char *message, ... )
{
    va_list ap;

    va_start( ap, message );
    vfprintf( stdout, message, ap );
    va_end( ap );

    fprintf( stdout, "\n" );
    fflush( stdout );

    exit(0);
}


/**************************************************************************************
**
**    Function: void log_message_debug
**
**    Purpose:  logs a message only if the DEBUG variable is defined.
**
**    Return:   none.
**
**************************************************************************************/

void log_message_debug( char *message, ... )
{
#ifdef DEBUG

    va_list ap;

    va_start( ap, message );
    vfprintf( stdout, message, ap );
    va_end( ap );

    fprintf( stdout, "\n" );
    fflush( stdout );

#endif
}

